==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/getwertvb.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getwertvb//
create function getwertvb(wid integer, von datetime(6), bis datetime(6), mode varchar(12))
                  returns varchar(20000)
deterministic
sql security invoker
begin
  declare i integer;
  declare wt varchar(30);
  declare e, w varchar(100);
  select wtab, einheiten.name from werteindizes, teststepdetails, einheiten
      where werteindizes.ID=wid and teststepdetailsID=teststepdetails.ID
        and einheitID=einheiten.ID
      into wt, e;
  case wt
    when 'bwerte' then return getbwertvb(wid, von, bis, mode);
    when 'swerte' then return getswertvb(wid, von, bis, mode);
    when 'twerte' then
        if e = '[E]' then
          select coalesce(wert,lastwert) from twerte, letztewerte
            where werteindizesID = wid and datum >= von and letztewerte.ID = wid
          limit 1 into e;
          set i = instr(e, ' ');
          if i > 0 then
            set e = substr(e, i+1);
            set w = getewertvbextfilteru(wid, von, bis, mode, '00:00:00', '23:59:59', '',
                      '', '', '', '', '',  '', '', '', '', '', '', e);
            if w = '' OR mode = 'count' OR mode like 'last/avg%' then
              return w;
            elseif mode = 'grad' then
              return concat(w, ' ', e, '/h');
            elseif mode = 'accel' then
              return concat(w, ' ', e, '/h²');
            else
              return concat(w, ' ', e);
            end if;
          else
            return '';
          end if;
      else
        return gettwertvb(wid, von, bis, mode);
      end if;
    when 'pwerte' then return getpwertvb(wid, von, bis, mode);
    when 'cwerte' then return getcwertvb(wid, von, bis, mode);
    else               return getzwertvb(wid, von, bis, mode);
  end case;
end//

GRANT EXECUTE on FUNCTION getwertvb to logginglesen@'localhost', loggingtest@'localhost', loggingadmin@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/getwertvb.sql <==
-- getwertvb.sql
--
-- function getwertvb(wid, von, bis, mode) returns varchar
-- wid: werteindizesID
-- von: datetime from
-- bis: datetime to
-- mode: aggregation function
-- return: aggragated value

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getwertvb//
create function getwertvb(wid integer, von datetime(6), bis datetime(6), mode varchar(12))
                  returns varchar(20000)
deterministic
sql security invoker
begin
  declare i integer;
  declare wt varchar(30);
  declare e, w varchar(100);

  select wtab, einheiten.name into wt, e from werteindizes, teststepdetails, einheiten
      where werteindizes.ID = wid and teststepdetailsID = teststepdetails.ID
        and einheitID = einheiten.ID;
  case wt
    when 'bwerte' then return getbwertvb(wid, von, bis, mode);
    when 'swerte' then return getswertvb(wid, von, bis, mode);
    when 'twerte' then
        if e = '[E]' then
          select coalesce(wert,lastwert) into e from twerte, letztewerte
            where werteindizesID = wid and datum >= von and letztewerte.ID = wid
          limit 1;
          set i = instr(e, ' ');
          if i > 0 then
            set e = substr(e, i+1);
            set w = getewertvbextfilteru(wid, von, bis, mode, '00:00:00', '23:59:59', '',
                      '', '', '', '', '',  '', '', '', '', '', '', e);
            if w = '' OR mode = 'count' OR mode like 'last/avg%' then
              return w;
            elseif mode = 'grad' then
              return concat(w, ' ', e, '/h');
            elseif mode = 'accel' then
              return concat(w, ' ', e, '/h²');
            else
              return concat(w, ' ', e);
            end if;
          else
            return '';
          end if;
      else
        return gettwertvb(wid, von, bis, mode);
      end if;
    when 'pwerte' then return getpwertvb(wid, von, bis, mode);
    when 'cwerte' then return getcwertvb(wid, von, bis, mode);
    else               return getzwertvb(wid, von, bis, mode);
  end case;
end//

GRANT EXECUTE on FUNCTION getwertvb to logginglesen@'localhost', loggingtest@'localhost', loggingadmin@'localhost'//
